@@ -13,8 +13,8 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-from octobot_backtesting.collectors.exchanges.exchange_collector import ExchangeDataCollector
+import octobot_backtesting.collectors.exchanges as exchanges
 
 
-class AbstractExchangeHistoryCollector(ExchangeDataCollector):
+class AbstractExchangeHistoryCollector(exchanges.ExchangeDataCollector):
     pass
